@@ -186,22 +186,19 @@ char *strparchr(char *p, char c)
 /* search for string, skipping parentheses */
 char *strparstr(char *p, char *fnd)
 {
-    char *pp, c;
-    int n;
-
-    if(*fnd==0) return p+strlen(p);
-    c=*fnd; n=strlen(fnd);
-    for(pp=p;pp-1!=NULL && *pp!=0; pp++) {
+    char *pp, c=*fnd;
+    size_t n = strlen(fnd);
+    /*if(*fnd==0) return p+strlen(p);*/
+    for(pp=p; *pp; pp++) {
       if(*pp==c && (n==1 || strncmp(pp,fnd,n)==0)) return pp;
       switch(*pp) {
           case '(': pp=find_matching(pp+1,')'); break;
           case '[': pp=find_matching(pp+1,']'); break;
           case '{': pp=find_matching(pp+1,'}'); break;
       }
+      if (!pp) { pp = strstr(p,fnd); if (!pp) pp = p+strlen(p); break; }
     }
-    if(pp-1==NULL) pp=strstr(p,fnd);
-    if(pp!=NULL) return pp;
-    else return p+strlen(p);
+    return pp;
 }
 
 /* Points to the end of an item */
@@ -420,13 +417,20 @@ char *fnd_line(char *p, int n, char bf[])
     char *pp;
     int i;
 
-    for(i=1,pp=p; pp-1!=NULL && *pp!=0 && i<n; pp=strchr(pp,'\n')+1, i++);
-    fnd_position=pp; if(pp-1==NULL) {
-      fnd_position=NULL; fnd_nextpos=""; *bf=0; return bf;
+    /*
+for(i=1,pp=p; pp-1!=NULL && *pp!=0 && i<n; pp=strchr(pp,'\n')+1, i++);
+    */
+    for(i=1,pp=p; i<n; i++) {
+        pp=strchr(pp,'\n');
+        if (!pp++) {
+          fnd_position=NULL; fnd_nextpos=""; *bf=0; return bf;
+        }
     }
+    fnd_position=pp;
     for(i=0; *(pp+i)!=0 && *(pp+i)!='\n'; i++) *(bf+i)=*(pp+i);
     *(bf+i)=0;
-    if(pp[i]=='\n') i++; fnd_nextpos=pp+i;
+    if(pp[i]=='\n') i++;
+    fnd_nextpos=pp+i;
     return bf;
 }
 
