@@ -371,6 +371,7 @@ void exec_read(char *p)
     if(outputing) phtml_put(p,cache); else var_proc(p,cache);
     readnest--; untrust=t;
     memmove(&m_file,&save,sizeof(WORKING_FILE));
+    if (trace_file) {fprintf(trace_file,"\n%s:",m_file.filepath); fflush(trace_file);}
     setvar("wims_read_parm",parmsave);
 }
 
@@ -517,25 +518,23 @@ void exec_formend(char *p)
 
 void determine_font(char *l);
 
+/* see changelog wims_mathml for history */
 void _headmathjax ( char *p)
 {
    _output_("\n<script type=\"text/javascript\">/*<![CDATA[*/\
 function wims_mathml_zoom(id){\
 var math = document.getElementById(id);\
 if(math.getAttribute(\"mathsize\") == \"100%\"){\
-math.setAttribute(\"mathsize\",\"200%\");}else{\
-math.setAttribute(\"mathsize\",\"100%\");};\
+  math.setAttribute(\"mathsize\",\"200%\");}else{\
+  math.setAttribute(\"mathsize\",\"100%\");};\
 };\
-if(\
-navigator.userAgent.toLowerCase().indexOf(\"firefox\") == -1 &&\
-navigator.userAgent.toLowerCase().indexOf(\"opera\") == -1 &&\
-(navigator.userAgent.toLowerCase().indexOf(\"safari\") == -1 ||\
- navigator.userAgent.toLowerCase().indexOf(\"chrome\") > 0 ||\
- navigator.userAgent.toLowerCase().indexOf(\"android\") > 0)\
-){var script = document.createElement(\"script\");\
-script.type = \"text/javascript\";\
-script.src  = \"scripts/js/mathjax/MathJax.js?config=MML_HTMLorMML-full.js\";\
-document.body.appendChild(script);\
+var ua = navigator.userAgent.toLowerCase();\
+var gecko = ua.indexOf(\"gecko\") > -1 && ua.indexOf(\"khtml\") === -1 && ua.indexOf(\"trident\") === -1;\
+if(! gecko ){\
+ var script = document.createElement(\"script\");\
+ script.type = \"text/javascript\";\
+ script.src  = \"scripts/js/mathjax/MathJax.js?config=MML_HTMLorMML-full.js\";\
+ document.body.appendChild(script);\
 };/*]]>*/</script>\n");
 }
 
