@@ -833,7 +833,9 @@ void var_proc(char *fname,int cache)
 
     if(fname!=NULL && read_module_file(fname)) return;
     if(untrust&6) get_var_privileges();
+    if (trace_file) {fprintf(trace_file,"\n%s:",m_file.filepath); fflush(trace_file);}
     while(m_file.linepointer<m_file.linecnt) {
+     if (trace_file) {fprintf(trace_file," %d",m_file.linepointer+1); fflush(trace_file); }
      t=m_file.lines[m_file.linepointer].isstart;
      if((t&~2)!=1 || m_file.lines[m_file.linepointer].llen==0) {
          m_file.linepointer++; continue;
@@ -843,7 +845,8 @@ void var_proc(char *fname,int cache)
      if((t&2)!=0) exec_main(p+1);
      else exec_set(p);
     }
-    close_working_file(&m_file,cache);
+     if (trace_file) fprintf(trace_file,"\n");
+     close_working_file(&m_file,cache);
 }
 
 /* Deposit the content of wims_deposit into a file */
@@ -1123,13 +1126,17 @@ void phtml_put(char *fname,int cache)
      /* File not found; we give empty output, but no error message. */
     if(fname!=NULL && read_module_file(fname)!=0) return;
     if(untrust&6) get_var_privileges();
+    if (trace_file) { fprintf(trace_file,"\n%s:",m_file.filepath); fflush(trace_file); }
     while(m_file.linepointer<m_file.linecnt) {
+	 if (trace_file) { fprintf(trace_file," %d",m_file.linepointer+1);
+	                   fflush(trace_file); }
      t=m_file.lines[m_file.linepointer].isstart;
      if((t&~18)!=1) {m_file.linepointer++; continue;}
      wgetline(tbuf,MAX_LINELEN,&m_file); substnest=0;
      if((t&2)!=0) {exec_main(tbuf+1); continue;}
      substit(tbuf); output0(tbuf); _output_("\n");
     }
+	if (trace_file) { fprintf(trace_file,"\n");fflush(trace_file); }
     close_working_file(&m_file,cache);
 }
 
